@@ -66,6 +66,7 @@ function torbutton_prefs_set_field_attributes(doc)
         doc.getElementById('torbutton_socksHost').disabled = true;
         doc.getElementById('torbutton_socksPort').disabled = true;
         doc.getElementById('torbutton_socksGroup').disabled = true;
+        doc.getElementById('torbutton_noProxiesOn').disabled = true;
     } else {
         doc.getElementById('torbutton_httpProxy').disabled = false;
         doc.getElementById('torbutton_httpPort').disabled = false;
@@ -78,6 +79,7 @@ function torbutton_prefs_set_field_attributes(doc)
         doc.getElementById('torbutton_socksHost').disabled = false;
         doc.getElementById('torbutton_socksPort').disabled = false;
         doc.getElementById('torbutton_socksGroup').disabled = false;
+        doc.getElementById('torbutton_noProxiesOn').disabled = false;
         /* Do not reset these on every document update..
         doc.getElementById('torbutton_httpProxy').value    = o_customprefs.getCharPref('http_proxy');
         doc.getElementById('torbutton_httpPort').value     = o_customprefs.getIntPref('http_port');
@@ -91,6 +93,8 @@ function torbutton_prefs_set_field_attributes(doc)
         doc.getElementById('torbutton_socksPort').value    = o_customprefs.getIntPref('socks_port');
         */
     }
+
+    doc.getElementById('torbutton_searchEngine').disabled = !doc.getElementById('torbutton_noCaptcha').checked;
 }
 
 function torbutton_prefs_init(doc) {
@@ -138,6 +142,8 @@ function torbutton_prefs_init(doc) {
         doc.getElementById('torbutton_socksGroup').selectedItem =
             doc.getElementById('torbutton_socksv5');    
     }
+    doc.getElementById('torbutton_noProxiesOn').value = o_torprefs.getCharPref('no_proxies_on');
+
     // doc.getElementById('torbutton_warnUponExcludedSite').checked = o_torprefs.getBoolPref('prompt_before_visiting_excluded_sites');
 
     doc.getElementById('torbutton_disablePlugins').checked = o_torprefs.getBoolPref('no_tor_plugins');
@@ -253,9 +259,9 @@ function torbutton_prefs_init(doc) {
     doc.getElementById('torbutton_blockNonTorForms').checked = o_torprefs.getBoolPref('block_ntforms');
     doc.getElementById('torbutton_isolateContent').checked = o_torprefs.getBoolPref('isolate_content');
     doc.getElementById('torbutton_noSearch').checked = o_torprefs.getBoolPref('no_search');
+    doc.getElementById('torbutton_disableLivemarks').checked = o_torprefs.getBoolPref('disable_livemarks');
     doc.getElementById('torbutton_closeTor').checked = o_torprefs.getBoolPref('close_tor');
     doc.getElementById('torbutton_closeNonTor').checked = o_torprefs.getBoolPref('close_nontor');
-    doc.getElementById('torbutton_noUpdates').checked = o_torprefs.getBoolPref('no_updates');
     doc.getElementById('torbutton_setUagent').checked = o_torprefs.getBoolPref('set_uagent');
     doc.getElementById('torbutton_noReferer').checked = o_torprefs.getBoolPref('disable_referer');
     doc.getElementById('torbutton_spoofEnglish').checked = o_torprefs.getBoolPref('spoof_english');
@@ -264,12 +270,39 @@ function torbutton_prefs_init(doc) {
     doc.getElementById('torbutton_blockTorFileNet').checked = o_torprefs.getBoolPref('block_tor_file_net');
     doc.getElementById('torbutton_blockNonTorFileNet').checked = o_torprefs.getBoolPref('block_nontor_file_net');
 
+    doc.getElementById('torbutton_fixGoogleSrch').checked = o_torprefs.getBoolPref('fix_google_srch');
     doc.getElementById('torbutton_lockedMode').checked = o_torprefs.getBoolPref('locked_mode');
+
+    switch(o_torprefs.getIntPref('google_redir_url')) {
+        case 1:
+            doc.getElementById("torbutton_searchEngine").selectedItem =
+                doc.getElementById('torbutton_engine1');
+            break;
+        case 2:
+            doc.getElementById("torbutton_searchEngine").selectedItem =
+                doc.getElementById('torbutton_engine2');
+            break;
+        case 3:
+            doc.getElementById("torbutton_searchEngine").selectedItem =
+                doc.getElementById('torbutton_engine3');
+            break;
+        case 4:
+            doc.getElementById("torbutton_searchEngine").selectedItem =
+                doc.getElementById('torbutton_engine4');
+            break;
+
+    }
+    doc.getElementById('torbutton_noCaptcha').checked = o_torprefs.getBoolPref('dodge_google_captcha');
+    doc.getElementById('torbutton_searchEngine').disabled = !o_torprefs.getBoolPref('dodge_google_captcha');
+
     /*
     doc.getElementById('torbutton_jarCerts').checked = o_torprefs.getBoolPref('jar_certs');
     doc.getElementById('torbutton_jarCACerts').checked = o_torprefs.getBoolPref('jar_ca_certs');
     */
 
+    doc.getElementById('torbutton_noUpdates').checked = o_torprefs.getBoolPref('no_updates');
+    doc.getElementById('torbutton_updateTorbuttonViaTor').checked = o_torprefs.getBoolPref('update_torbutton_via_tor');
+
     torbutton_prefs_set_field_attributes(doc);
 }
 
@@ -307,6 +340,17 @@ function torbutton_prefs_save(doc) {
     var o_torprefs = torbutton_get_prefbranch('extensions.torbutton.');
     var o_customprefs = torbutton_get_prefbranch('extensions.torbutton.custom.');
 
+    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
+        .getService(Components.interfaces.nsIWindowMediator);
+    var enumerator = wm.getEnumerator("navigator:browser");
+    while(enumerator.hasMoreElements()) {
+        var win = enumerator.getNext();
+        if(win != window && win.m_tb_is_main_window) {
+            torbutton_log(3, "Found main window for popup hack.");
+            win.torbutton_unique_pref_observer.did_toggle_warning = false;
+        }
+    }
+
     o_torprefs.setBoolPref('display_panel',   doc.getElementById('torbutton_displayStatusPanel').checked);
     o_torprefs.setCharPref('panel_style',     doc.getElementById('torbutton_panelStyle').value);
     o_torprefs.setCharPref('settings_method', doc.getElementById('torbutton_settingsMethod').value);
@@ -330,6 +374,8 @@ function torbutton_prefs_save(doc) {
         o_torprefs.setIntPref('socks_version', 5); 
     }
 
+    o_torprefs.setCharPref('no_proxies_on',      doc.getElementById('torbutton_noProxiesOn').value);
+    
     if (doc.getElementById('torbutton_settingsMethod').value == 'custom') {
         // XXX: Is this even needed anymore? We don't read the
         // custom prefs at all it seems..
@@ -418,15 +464,32 @@ function torbutton_prefs_save(doc) {
     o_torprefs.setBoolPref('block_tforms', doc.getElementById('torbutton_blockTorForms').checked);
     o_torprefs.setBoolPref('block_ntforms', doc.getElementById('torbutton_blockNonTorForms').checked);
     o_torprefs.setBoolPref('no_search', doc.getElementById('torbutton_noSearch').checked);
+    o_torprefs.setBoolPref('disable_livemarks', doc.getElementById('torbutton_disableLivemarks').checked);
     o_torprefs.setBoolPref('close_tor', doc.getElementById('torbutton_closeTor').checked);
     o_torprefs.setBoolPref('close_nontor', doc.getElementById('torbutton_closeNonTor').checked);
     o_torprefs.setBoolPref('no_updates', doc.getElementById('torbutton_noUpdates').checked);
-    
+
     o_torprefs.setBoolPref('set_uagent', doc.getElementById('torbutton_setUagent').checked);
     o_torprefs.setBoolPref('disable_referer', doc.getElementById('torbutton_noReferer').checked);
     o_torprefs.setBoolPref('spoof_english', doc.getElementById('torbutton_spoofEnglish').checked);
-    
+
     o_torprefs.setBoolPref('locked_mode', doc.getElementById('torbutton_lockedMode').checked);
+    o_torprefs.setBoolPref('fix_google_srch', doc.getElementById('torbutton_fixGoogleSrch').checked);
+    o_torprefs.setBoolPref('dodge_google_captcha', doc.getElementById('torbutton_noCaptcha').checked);
+
+    if(doc.getElementById('torbutton_searchEngine').selectedItem ==
+            doc.getElementById('torbutton_engine1')) {
+        o_torprefs.setIntPref('google_redir_url', 1);
+    } else if(doc.getElementById('torbutton_searchEngine').selectedItem ==
+            doc.getElementById('torbutton_engine2')) {
+        o_torprefs.setIntPref('google_redir_url', 2);
+    } else if(doc.getElementById('torbutton_searchEngine').selectedItem ==
+            doc.getElementById('torbutton_engine3')) {
+        o_torprefs.setIntPref('google_redir_url', 3);
+    } else {
+        o_torprefs.setIntPref('google_redir_url', 4);
+    }
+
     /*
     o_torprefs.setBoolPref('jar_certs', doc.getElementById('torbutton_jarCerts').checked);
     o_torprefs.setBoolPref('jar_ca_certs',
@@ -434,6 +497,11 @@ function torbutton_prefs_save(doc) {
             doc.getElementById('torbutton_jarCACerts').checked);
     */
 
+    o_torprefs.setBoolPref('no_updates',
+            doc.getElementById('torbutton_noUpdates').checked);
+    o_torprefs.setBoolPref('update_torbutton_via_tor',
+            doc.getElementById('torbutton_updateTorbuttonViaTor').checked);
+
     // if tor settings were initially active, update the active settings to reflect any changes
     if (tor_enabled) torbutton_activate_tor_settings();
 }
@@ -460,7 +528,7 @@ function torbutton_prefs_test_settings() {
         window.alert("Tor proxy test: HTTP error for check.torproject.org: "+ret);
         return;
     }
-            
+
     switch(ret) {
         case 0:
             window.alert("Tor proxy test: Internal error");
@@ -488,6 +556,10 @@ function torbutton_prefs_test_settings() {
         case 7:
             window.alert("Tor proxy test: check.torproject.org returned bad result");
             break;
+        case 8:
+            var warning = strings.GetStringFromName("torbutton.popup.test.no_http_proxy");
+            window.alert(warning);
+            break;
     }
 }
 
