@@ -4,7 +4,11 @@ var m_tb_torlog = Components.classes["@torproject.org/torbutton-logger;1"]
 
 function torbutton_eclog(nLevel, sMsg) {
     m_tb_torlog.eclog(nLevel, sMsg);
+    return true;
+}
 
+function torbutton_safelog(nLevel, sMsg, scrub) {
+    m_tb_torlog.safe_log(nLevel, sMsg, scrub);
     return true;
 }
 
@@ -83,6 +87,7 @@ function torbutton_check_socks_remote_dns()
 function torbutton_check_status() {
     var liveprefs = false;
     var torprefs = false;
+    var remote_dns = true;
     torbutton_log(1, "Check status");
 
     liveprefs = torbutton_get_prefbranch('network.proxy.');
@@ -159,6 +164,7 @@ function torbutton_activate_tor_settings()
   liveprefs.setCharPref('socks',        torprefs.getCharPref('socks_host'));
   liveprefs.setIntPref('socks_port',    torprefs.getIntPref('socks_port'));
   liveprefs.setIntPref('socks_version', torprefs.getIntPref('socks_version'));
+  liveprefs.setCharPref('no_proxies_on', torprefs.getCharPref('no_proxies_on'));
   liveprefs.setBoolPref('share_proxy_settings', false);
   if (torbutton_check_socks_remote_dns()) {
       liveprefs.setBoolPref('socks_remote_dns', true);
