@@ -95,12 +95,16 @@ var localSchemes = {"about" : true, "chrome" : true, "file" : true,
     "resource" : true, "x-jsd" : true, "addbook" : true, 
     "mailbox" : true, "moz-icon" : true};
 
-var browserSources = { "browser":true, "mozapps":true, "global":true, 
-     "pippki":true, "branding":true};
+var browserSources = { "browser":true, "mozapps":true, "global":true,
+     "pippki":true, "branding":true, "cookie":true, "xbl-marquee":true,
+     "reporter":true, "global-region":true, "passwordmgr":true,
+     "global-platform":true};
 
 var hostFreeSchemes = { "resource":true, "data":true, "cid":true, 
      "file":true, "view-source":true, "about":true};
 
+var protectedChromeHosts = { "torbutton": true };
+
 function ContentPolicy() {
     this.logger = Components.classes["@torproject.org/torbutton-logger;1"]
         .getService(Components.interfaces.nsISupports).wrappedJSObject;
@@ -126,6 +130,7 @@ function ContentPolicy() {
     this.block_nontor_file_net = this._prefs.getBoolPref("extensions.torbutton.block_nontor_file_net");
     this.no_tor_plugins = this._prefs.getBoolPref("extensions.torbutton.no_tor_plugins");
 
+    this.wrappedJSObject = this;
     return;
 }
 
@@ -176,7 +181,8 @@ ContentPolicy.prototype = {
                                       contentLocation.spec);
                     return ok;
                 }
-                this.logger.eclog(4, "NO ORIGIN! Blockng request for: "+contentLocation.spec);
+                this.logger.safe_log(4, "NO ORIGIN! Blockng request for: ", 
+                        contentLocation.spec);
                 return block;
             }
         } else {
@@ -218,17 +224,20 @@ ContentPolicy.prototype = {
                 } else {
                     if (this.block_tor_file_net && this.tor_enabling ||
                             this.block_nontor_file_net && !this.tor_enabling) {
-                        this.logger.eclog(4, "Blocking remote request from: " +
-                                          requestOrigin.spec + " for: " +
-                                          contentLocation.spec);
+                        this.logger.safe_log(4, "Blocking remote request from: ",
+                                 requestOrigin.spec+" for: "
+                                 +contentLocation.spec);
                         return block;
                     }
                 }
                 break;
             case "moz-nullprincipal":
-                // forbidden
-                if (this.tor_enabling) {
-                    this.logger.eclog(4, "Blocking request from: " +
+                // forbidden to access anything but chrome
+                // (Chrome access needed for FoxyProxy context menu)
+                if (this.tor_enabling && 
+                        (contentLocation.scheme != "chrome")) {
+                    this.logger.safe_log(4, 
+                            "Blocking nullprinciple request from: ",
                                       requestOrigin.spec + " for: " +
                                       contentLocation.spec);
                     return block;
@@ -242,7 +251,7 @@ ContentPolicy.prototype = {
                         try {
                             targetHost = contentLocation.host;
                         } catch(e) {
-                            this.logger.eclog(4, "No host from: " +
+                            this.logger.safe_log(4, "No host from: ",
                                     requestOrigin.spec + " for: " +
                                     contentLocation.spec);
                         }
@@ -255,10 +264,20 @@ ContentPolicy.prototype = {
                                           requestOrigin.spec + " for: " +
                                           contentLocation.spec);
                         return ok;
+                    } else if ("file" == targetScheme) {
+                        // This fix is for bug 1014. XHTML documents need to source
+                        // a special dtd as a file url. The same origin policy should
+                        // prevent other access to file urls, so this should be ok
+                        // to just allow.
+                        this.logger.eclog(3, "Allowing browser file request from: " +
+                                          requestOrigin.spec + " for: " +
+                                          contentLocation.spec);
+                        //return ok;
                     } else {
-                        if (this.tor_enabling || ("torbutton" == targetHost)) {
-                            this.logger.eclog(4, "Blocking local request from: "
-                                              +requestOrigin.spec+" ("
+                        if (this.tor_enabling || (targetHost in protectedChromeHosts)) {
+                            this.logger.safe_log(4,
+                                    "Blocking local request from: ",
+                                              requestOrigin.spec+" ("
                                               +requestOrigin.scheme+") for: "+
                                               contentLocation.spec);
                             return block;
@@ -282,13 +301,15 @@ ContentPolicy.prototype = {
             // could handle it either here or shouldProcess, instead of in 
             // the webprogresslistener
             if(this.tor_enabling && this.no_tor_plugins) {
-                this.logger.log(4, "Blocking object at "+contentLocation.spec);
+                this.logger.safe_log(4, "Blocking object at ",
+                                     contentLocation.spec);
                 return block;
             }
         }
 
         if (!wind || !wind.top.location || !wind.top.location.href) {
-            this.logger.log(4, "Skipping no location: "+contentLocation.spec);
+            this.logger.safe_log(4, "Skipping no location: ",
+                                 contentLocation.spec);
 			return ok;
         }
 
@@ -347,14 +368,14 @@ ContentPolicy.prototype = {
                     if(!requestOrigin.schemeIs("chrome")) {
                         if(typeof(browser.__tb_tor_fetched) == 'undefined') {
                             // This happens for "open in new window" context menu
-                            this.logger.log(3, "Untagged window for redirect "+contentLocation.spec);
+                            this.logger.safe_log(3, "Untagged window for redirect: ", contentLocation.spec);
                             return ok;
                         }
                         if(browser.__tb_tor_fetched == this.tor_enabled
                                 && browser.__tb_tor_fetched == this.settings_applied) {
                             return ok;
                         } else {
-                            this.logger.log(4, "Blocking redirect: "+contentLocation.spec);
+                            this.logger.safe_log(4, "Blocking redirect: ", contentLocation.spec);
                             return block;
                         }
                     }
@@ -367,7 +388,8 @@ ContentPolicy.prototype = {
                 && browser.__tb_tor_fetched == this.settings_applied) {
             return ok;
         } else {
-            this.logger.log(4, "Blocking cross state load of: "+contentLocation.spec);
+            this.logger.safe_log(4, "Blocking cross-state load of: ",
+                          contentLocation.spec);
             return block;
         }
 	},
@@ -413,6 +435,11 @@ ContentPolicy.prototype = {
                 this.no_tor_plugins = this._prefs.getBoolPref("extensions.torbutton.no_tor_plugins");
                 break;
         }
+    },
+
+    // API to add another addon to be protected from discovery
+    addProtectedChromeHost: function(name) {
+        protectedChromeHosts[name] = true;
     }
 };
 
