@@ -105,7 +105,8 @@ var appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
 var versionChecker = Components.classes["@mozilla.org/xpcom/version-comparator;1"]
   .getService(Components.interfaces.nsIVersionComparator);
 
-if(versionChecker.compare(appInfo.version, "3.0a1") >= 0) {
+if(versionChecker.compare(appInfo.version, "3.0a1") >= 0
+        && versionChecker.compare(appInfo.version, "3.5a1") <= 0) {
     is_FF3 = true;
     // module for JSON conversion (needed for the nsISessionStore API)
     Cu.import("resource://gre/modules/JSON.jsm");
@@ -394,8 +395,13 @@ SessionStoreService.prototype = {
         break;
       case "TabOpen":
       case "TabClose":
-        var panelID = aEvent.originalTarget.linkedPanel;
-        var tabpanel = aEvent.originalTarget.ownerDocument.getElementById(panelID);
+        let target = aEvent.originalTarget;
+        let panelID = target.linkedPanel;
+        let ownerDoc = target.ownerDocument;
+        let bindingParent = ownerDoc.getBindingParent(target);
+        let tabpanel =
+          ownerDoc.getAnonymousElementByAttribute(bindingParent, "id",
+                                                  panelID);
         if (aEvent.type == "TabOpen") {
           this.onTabAdd(aEvent.currentTarget.ownerDocument.defaultView, tabpanel);
         }
