@@ -21,8 +21,7 @@ const nsIComponentRegistrar = Components.interfaces.nsIComponentRegistrar;
 const nsIObserverService = Components.interfaces.nsIObserverService;
 
 function ContentWindowMapper() {
-    this.cache = new Object();
-    this.cache["bah"] = 0;
+    this.cache = {};
 
     this.logger = Components.classes["@torproject.org/torbutton-logger;1"]
         .getService(Components.interfaces.nsISupports).wrappedJSObject;
@@ -87,13 +86,18 @@ ContentWindowMapper.prototype =
           return;
       }
 
+      var delkeys = [];
       for(var elem in this.cache) {
           if((now - this.cache[elem].time) > EXPIRATION_TIME) {
               this.logger.log(2, "Deleting cached element: "+elem.location);
-              delete this.cache[elem];
+              delkeys.push(elem);
           }
       }
 
+      for(var k in delkeys) {
+        delete this.cache[k];
+      }
+
       this.last_expired = now;
   },
 
@@ -143,9 +147,9 @@ ContentWindowMapper.prototype =
       try {
           if(topContentWindow.name != "speedDialLoaderBrowser") {
               if(topContentWindow && topContentWindow.location)
-                  this.logger.log(4, "No browser found: "+topContentWindow.location);
+                  this.logger.safe_log(4, "No browser found: ", topContentWindow.location);
               else
-                  this.logger.log(4, "No browser found: "+topContentWindow.name);
+                  this.logger.safe_log(4, "No browser found: ", topContentWindow.name);
           } else {
               this.logger.log(3, "SpeedDial browser found: "+topContentWindow.name);
           }
