@@ -1,7 +1,7 @@
 // debug prefs
 pref("extensions.torbutton.debug",true);
 pref("extensions.torbutton.loglevel",4);
-pref("extensions.torbutton.logmethod",2); // 0=stdout, 1=errorconsole, 2=debuglog
+pref("extensions.torbutton.logmethod",1); // 0=stdout, 1=errorconsole, 2=debuglog
 
 // Display prefs
 pref("extensions.torbutton.display_panel",true);
@@ -25,6 +25,7 @@ pref("extensions.torbutton.socks_version",5);
 pref("extensions.torbutton.locked_mode",false);
 pref("extensions.torbutton.test_url","https://check.torproject.org/?TorButton=true");
 pref("extensions.torbutton.test_failed",false);
+pref("extensions.torbutton.no_proxies_on","127.0.0.1");
 
 // XXX: wtf prefs? These seem not actually connected, but govern
 // if user wants own tor proxy settings
@@ -54,6 +55,7 @@ pref("extensions.torbutton.saved.socks_host","");
 pref("extensions.torbutton.saved.socks_version",0);
 pref("extensions.torbutton.saved.socks_port",0);
 pref("extensions.torbutton.saved.socks_remote_dns",false);
+pref("extensions.torbutton.saved.no_proxies_on","localhost, 127.0.0.1");
 
 pref("extensions.torbutton.saved.cookieLifetime",0);
 pref("extensions.torbutton.saved.full_page_plugins","");
@@ -65,16 +67,31 @@ pref("extensions.torbutton.saved.expire_history", 9);
 pref("extensions.torbutton.saved.download_retention", 2);
 pref("extensions.torbutton.saved.formfill", true);
 pref("extensions.torbutton.saved.remember_signons", true);
-pref("extensions.torbutton.saved.livemark_refresh", 0);
 pref("extensions.torbutton.saved.sendSecureXSiteReferrer", true);
 pref("extensions.torbutton.saved.sendRefererHeader", 2);
 pref("extensions.torbutton.saved.dom_storage", true);
 pref("extensions.torbutton.saved.mem_cache", true);
+pref("extensions.torbutton.saved.offline_cache", true);
 pref("extensions.torbutton.saved.http_cache", true);
 pref("extensions.torbutton.saved.extension_update", true);
 pref("extensions.torbutton.saved.app_update", true);
 pref("extensions.torbutton.saved.auto_update", true);
 pref("extensions.torbutton.saved.search_update", true);
+pref("extensions.torbutton.saved.geo_enabled", true);
+pref("extensions.torbutton.saved.zoom_specific", true);
+pref("extensions.torbutton.saved.accept_languages", "");
+pref("extensions.torbutton.saved.accept_charsets", "");
+pref("extensions.torbutton.saved.appname_override","");
+pref("extensions.torbutton.saved.appversion_override","");
+pref("extensions.torbutton.saved.platform_override","");
+pref("extensions.torbutton.saved.oscpu_override", "");
+pref("extensions.torbutton.saved.useragent_override", "");
+pref("extensions.torbutton.saved.productsub_override","");
+pref("extensions.torbutton.saved.buildID_override","");
+pref("extensions.torbutton.saved.useragent_vendor", "");
+pref("extensions.torbutton.saved.useragent_vendorSub","");
+// network.dns.disablePrefetch is a hidden option. It has no default value:
+//pref("extensions.torbutton.saved.dns_prefetch", false);
 
 // State prefs:
 pref("extensions.torbutton.tor_enabled",false);
@@ -134,15 +151,45 @@ pref("extensions.torbutton.block_remoting",false);
 pref("extensions.torbutton.tor_memory_jar",false);
 pref("extensions.torbutton.nontor_memory_jar",false);
 pref("extensions.torbutton.tz_string","");
+pref("extensions.torbutton.launch_warning",true);
+pref("extensions.torbutton.disable_livemarks",true);
+pref("extensions.torbutton.update_torbutton_via_tor",true);
+
+// Google Captcha prefs
+// FIXME: NID cookie?
+pref("extensions.torbutton.gss_cookie", "Q0=dGVzdA");
+pref("extensions.torbutton.gnid_cookie", "28=aJDrQUM1UIWu1dl1tLMdzsi4trVtb8wayv4C2BCLPfjgQ2PlN7Pubc8UB9pYdMqGnzzCu95eXXB8MPhXVCC3o9SmJm_tQv8A4V2UZ4zoKKmrJqxcB1q00c2WxRJZD0uH");
+pref("extensions.torbutton.gsnid_cookie", "28=IY3ya2lsYwatvtjgr_zCzNaL0fU4LRusf1tJ-bRd-g=_qqMP84CMW2_bUOT");
+pref("extensions.torbutton.gpref_cookie", "ID=b7d8832732f59bb2:U=d7bc4e42b53ea8b5:TM=1256941064:LM=1256941222:S=AUWTvLPhx8FcIgYc");
+pref("extensions.torbutton.ggdsess_cookie", "ID=b7d8832732f59bb2:EX=1256952014:S=4CLFlq6bPRmEtd8c");
+pref("extensions.torbutton.gs_cookie", "sorry=zDHg1z1zi0BRXVKRrIaH2Q");
+pref("extensions.torbutton.google_host", ".google.ca");
+// Reset the google cookie to pref on cookie-changed:clear events
+pref("extensions.torbutton.reset_google_cookies", false);
+// Regen the google cookie on cookie-changed:clear events via a fetch
+pref("extensions.torbutton.regen_google_cookies", false);
+// Xfer google search cookies across all google domains
+pref("extensions.torbutton.xfer_google_cookies", true);
+
+// Google redirect prefs
+pref("extensions.torbutton.google_redir_url", 1);
+pref("extensions.torbutton.dodge_google_captcha", true);
+pref("extensions.torbutton.asked_google_captcha", false);
+pref("extensions.torbutton.redir_url.1", "https://www.ixquick.com/do/metasearch.pl?query=");
+pref("extensions.torbutton.redir_url.2", "http://www.bing.com/search?q=");
+pref("extensions.torbutton.redir_url.3", "http://search.yahoo.com/search?p=");
+pref("extensions.torbutton.redir_url.4", "https://ssl.scroogle.org/cgi-bin/nbbwssl.cgi?Gw=");
+pref("extensions.torbutton.fix_google_srch", true);
 
 // User agent prefs:
 pref("extensions.torbutton.appname_override","Netscape");
 pref("extensions.torbutton.appversion_override","5.0 (Windows; LANG)");
 pref("extensions.torbutton.platform_override","Win32");
-pref("extensions.torbutton.oscpu_override", "Windows NT 5.1");
-pref("extensions.torbutton.useragent_override", "Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.9.0.7) Gecko/2009021910 Firefox/3.0.7");
+pref("extensions.torbutton.oscpu_override", "Windows NT 6.1");
 
-pref("extensions.torbutton.productsub_override","2009021910");
+pref("extensions.torbutton.useragent_override", "Mozilla/5.0 (Windows; U; Windows NT 6.1; LANG; rv:1.9.2.3) Gecko/20100401 Firefox/3.6.3");
+
+pref("extensions.torbutton.productsub_override","20100401");
 pref("extensions.torbutton.buildID_override","0");
 pref("extensions.torbutton.useragent_vendor", "");
 pref("extensions.torbutton.useragent_vendorSub","");
