@@ -3,16 +3,18 @@
 
 LOCALEDIR="../src/chrome/locale"
 
-directories="ar de-DE es hr-HR nl-NL pt-BR sl-SI de-AT el-GR fa-IR it-IT pl-PL zh-CN de-CH fr-FR ru zh-TW"
 poDir="pootle" 
+directories="`ls -1 ./$poDir|tr _ -`"
 mozDir="moz"
-input="en-US"
+input="en"
 template="torbutton.dtd"
 
 for dir in $directories
 do
     pootleDir="`echo $dir|tr - _`";
+    echo "$pootleDir"
     mkdir -p $mozDir/$dir/
     po2moz -i $poDir/$pootleDir/ -t ${LOCALEDIR}/${input}/ -o $mozDir/$dir/ 
+    #po2moz -i $poDir/$pootleDir/ -t pootle/templates/ -o $mozDir/$dir/ 
 done
 
